@@ -5,14 +5,17 @@ Models.py
 
 Author: Derek Stegelman
 """
+from __future__ import unicode_literals
+
 import datetime
 
 from time import mktime
 
+from django.utils.encoding import python_2_unicode_compatible
 from django.db import models
 from django.contrib.auth.models import User
 from django.conf import settings
-
+from django.utils import timezone
 
 from feedme.utils import unique_slugify
 
@@ -21,6 +24,7 @@ import feedparser
 from .managers import FeedItemManager
 
 
+@python_2_unicode_compatible
 class Category(models.Model):
     """
     Category model
@@ -29,7 +33,7 @@ class Category(models.Model):
     slug = models.SlugField(blank=True, null=True, editable=False)
     user = models.ForeignKey(User, blank=True, null=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def save(self, *args, **kwargs):
@@ -51,6 +55,7 @@ class Category(models.Model):
         return FeedItem.objects.my_feed_items(self.user).category(self.slug).un_read().count()
 
 
+@python_2_unicode_compatible
 class Feed(models.Model):
     """
     Feed Model
@@ -67,7 +72,7 @@ class Feed(models.Model):
             ("url", "user"),
         )
 
-    def __unicode__(self):
+    def __str__(self):
         return self.url
 
     def _get_title(self):
@@ -108,6 +113,7 @@ class Feed(models.Model):
         un-read.
         """
         # Update the last update field
+        counter = 0
         feed = feedparser.parse(self.url)
         self.last_update = datetime.date.today()
         if "link" in feed.feed:
@@ -127,6 +133,7 @@ class Feed(models.Model):
                 FeedItem.objects.get(guid=guid)
             except FeedItem.DoesNotExist:
                 # Create it.
+                counter += 1
                 if "published_parsed" in item:
                     pub_date = datetime.datetime.fromtimestamp(mktime(item.published_parsed))
                 elif "updated_parsed" in item:
@@ -134,9 +141,12 @@ class Feed(models.Model):
                 else:
                     pub_date = datetime.datetime.now()
 
+                pub_date = timezone.make_aware(pub_date, timezone.get_current_timezone())
+
                 feed_item = FeedItem(title=item.title, link=item.link, content=item.description,
                                      guid=guid, pub_date=pub_date, feed=self)
                 feed_item.save()
+        return counter
 
     def _update_processor(self):
         """
@@ -171,6 +181,7 @@ class Feed(models.Model):
         return ('feedme-feed-list-by-feed', (), {'feed_id': self.id})
 
 
+@python_2_unicode_compatible
 class FeedItem(models.Model):
     """
     FeedItem Model
@@ -189,7 +200,7 @@ class FeedItem(models.Model):
     class Meta:
         ordering = ['id']
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
     def mark_as_read(self):
@@ -198,4 +209,3 @@ class FeedItem(models.Model):
         """
         self.read = True
         self.save()
-
